@@ -13,6 +13,7 @@ import attr
 import curlify
 import requests
 
+from .cwe import CWE
 from .events import Payload
 from .failures import Evidence
 from .status import Status
@@ -66,7 +67,7 @@ class AssertionResult:
     solution: Optional[str] = attr.ib(default=None)
     message: Optional[str] = attr.ib(default=None)
     code: Optional[str] = attr.ib(default=None)
-    cwe: Optional[str] = attr.ib(factory=str)
+    cwe: Optional[CWE] = attr.ib(default=None)
 
 
 @attr.s(slots=True, repr=False)
@@ -310,6 +311,16 @@ class SerializedError:
         )
 
 
+@attr.s(slots=True)
+class SerializedCWE:
+    code: int = attr.ib()
+    summary: str = attr.ib()
+
+    @classmethod
+    def from_cwe(cls, cwe: CWE) -> SerializedCWE:
+        return cls(code=cwe.code, summary=cwe.summary)
+
+
 @attr.s(slots=True)
 class SerializedAssertionResult:
     name: str = attr.ib()
@@ -324,7 +335,7 @@ class SerializedAssertionResult:
     solution: Optional[str] = attr.ib()
     message: Optional[str] = attr.ib()
     code: Optional[str] = attr.ib()
-    cwe: Optional[str] = attr.ib()
+    cwe: Optional[SerializedCWE] = attr.ib()
 
     @classmethod
     def from_assertion_result(
@@ -346,7 +357,11 @@ class SerializedAssertionResult:
             solution=assertion_result.solution,
             message=assertion_result.message,
             code=assertion_result.code,
-            cwe=assertion_result.cwe,
+            cwe=(
+                SerializedCWE.from_cwe(assertion_result.cwe)
+                if assertion_result.cwe
+                else None
+            ),
         )
 
 
